@@ -1,5 +1,3 @@
-/* $Id: procopenfiles.c 2422 2005-12-12 09:38:15Z jamesh $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    Copyright (C) 2004 Nicols Lichtmaier
    This file is part of LibGTop 1.0.
@@ -39,7 +37,7 @@ static const unsigned long _glibtop_sysdeps_proc_open_files =
 /* Init function. */
 
 void
-glibtop_init_proc_open_files_s (glibtop *server)
+_glibtop_init_proc_open_files_s (glibtop *server)
 {
 	server->sysdeps.proc_open_files = _glibtop_sysdeps_proc_open_files;
 }
