@@ -1,3 +1,4 @@
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/fsusage.h>
 
@@ -17,7 +18,7 @@
 void
 _glibtop_linux_get_fsusage_read_write(glibtop *server,
 				      glibtop_fsusage *buf,
-				      const char *path) G_GNUC_INTERNAL;
+				      const char *path);
 
 /*
  * Linux 2.6.x
@@ -38,7 +39,8 @@ get_partition(const char *mountpoint)
 	if(stat(mountpoint, &statb) == -1)
 		return NULL;
 
-	g_return_val_if_fail((partitions = fopen("/proc/partitions", "r")), NULL);
+	if((partitions = fopen("/proc/partitions", "r")) == NULL)
+		return NULL;
 
 	while(fgets(line, sizeof line, partitions))
 	{
@@ -60,8 +62,8 @@ get_partition(const char *mountpoint)
 }
 
 
-static char *
-get_sys_path(const char *device)
+static void
+get_sys_path(const char *device, char **stat_path, const char **parse_format)
 {
 	if(g_str_has_prefix(device, "hd") || g_str_has_prefix(device, "sd"))
 	{
@@ -78,12 +80,14 @@ get_sys_path(const char *device)
 				       prefix, device);
 
 		g_free(prefix);
-		return path;
 
+		*stat_path = path;
+		*parse_format = "%*llu %llu %*llu %llu";
 	}
 	else
 	{
-		return g_strdup_printf("/sys/block/%s/stat", device);
+		*stat_path = g_strdup_printf("/sys/block/%s/stat", device);
+		*parse_format = "%*llu %*llu %llu %*llu %*llu %*llu %llu";
 	}
 }
 
@@ -93,26 +97,26 @@ static void linux_2_6_0(glibtop *server, glibtop_fsusage *buf, const char *path)
 {
 	char *device;
 	char *filename;
+	const char *format;
 	int ret;
 	char buffer[BUFSIZ];
-	char *p;
 
 	device = get_partition(path);
 	if(!device) return;
 
-	filename = get_sys_path(device);
+	get_sys_path(device, &filename, &format);
 	g_free(device);
 
 	ret = try_file_to_buffer(buffer, filename);
-	g_free(filename);
 
 	if(ret < 0) return;
 
-	p = buffer;
-	p = skip_token(p);
-	buf->read = strtoull(p, &p, 0);
-	p = skip_token(p);
-	buf->write = strtoull(p, &p, 0);
+	if (sscanf(buffer, format, &buf->read, &buf->write) != 2) {
+		glibtop_warn_io_r(server, "Could not parse %s", filename);
+		return;
+	}
+
+	g_free(filename);
 
 	buf->flags |= (1 << GLIBTOP_FSUSAGE_READ) | (1 << GLIBTOP_FSUSAGE_WRITE);
 }
@@ -123,7 +127,7 @@ static void linux_2_4_0(glibtop *server, glibtop_fsusage *buf, const char *path)
 }
 
 
-void G_GNUC_INTERNAL
+void
 _glibtop_linux_get_fsusage_read_write(glibtop *server,
 				      glibtop_fsusage *buf,
 				      const char *path)
