@@ -58,7 +58,7 @@ static const unsigned long _glibtop_sysdeps_map_entry_smaps =
 /* Init function. */
 
 void
-glibtop_init_proc_map_s (glibtop *server)
+_glibtop_init_proc_map_s (glibtop *server)
 {
 	server->sysdeps.proc_map = _glibtop_sysdeps_proc_map;
 }
@@ -133,8 +133,6 @@ glibtop_get_proc_map_s (glibtop *server, glibtop_proc_map *buf,	pid_t pid)
 	char *line = NULL;
 	size_t line_size = 0;
 
-	glibtop_init_s (&server, GLIBTOP_SYSDEPS_PROC_MAP, 0);
-
 	memset (buf, 0, sizeof (glibtop_proc_map));
 
 	has_smaps = server->os_version_code >= LINUX_VERSION_CODE(2, 6, 14);
