@@ -37,7 +37,7 @@ static const unsigned long _glibtop_sysdeps_proc_state_uid =
 /* Init function. */
 
 void
-glibtop_init_proc_state_s (glibtop *server)
+_glibtop_init_proc_state_s (glibtop *server)
 {
 	server->sysdeps.proc_state = _glibtop_sysdeps_proc_state |
 		_glibtop_sysdeps_proc_state_uid;
@@ -51,8 +51,6 @@ glibtop_get_proc_state_s (glibtop *server, glibtop_proc_state *buf, pid_t pid)
 	char buffer [BUFSIZ], *p;
 	struct stat statb;
 
-	glibtop_init_s (&server, GLIBTOP_SYSDEPS_PROC_STATE, 0);
-
 	memset (buf, 0, sizeof (glibtop_proc_state));
 
 	/* IMPORTANT NOTICE: For security reasons it is extremely important
