@@ -1,5 +1,3 @@
-/* $Id: open.c,v 1.19 2004/06/09 18:52:22 bdejean Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -21,6 +19,10 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
+#include <glib/gstrfuncs.h>
+#include <errno.h>
+
 #include <glibtop.h>
 #include <glibtop/open.h>
 
@@ -257,7 +259,7 @@ _glibtop_getkval (void *void_server, unsigned long offset, int *ptr,
 			if (*refstr == '!') return 0;
 
 			glibtop_error_r (server, "kvm_read(%s): %s",
-					 refstr, strerror (errno));
+					 refstr, g_strerror (errno));
 		}
 
 	return 1;
